# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports = [
    ../hardware/apu.nix
    ../hardware/wle200nx.nix
    ../role/base
    ../role/router
    ../role/router-dns
    ../role/router-wireless-ap
  ];

  fileSystems."/" = {
    device = "/dev/disk/by-uuid/16efc5db-0697-4f39-b64b-fc18ac318625";
    fsType = "btrfs";
    options = [ "defaults" "subvol=nixos" "noatime" ];
  };

  swapDevices =
    [{ device = "/dev/disk/by-uuid/b5104a7c-4a4a-4048-a9f8-44ddb0082632"; }];

  services.router = {
    enable = true;
    wanInterface = "enp4s0";
    wirelessInterfaces = [ "wlp5s0" ];
    lanInterfaces = [ "enp2s0" ];
    internalRouterIP = "10.2.1.1";
    dhcp = {
      enable = true;
      localDomain = "ilanz.fh2.ch";
      dhcpRange = "10.1.1.2,10.1.1.249";
    };
    recursiveDns = {
      enable = true;
      networkIdIp = "10.1.1.0";
    };
    wireless = {
      enable = true;
      wleInterface24Ghz = "wlp5s0";
      #wleInterface5Ghz = "wlp5s0";
      ssid = "hauser";
      passphrase = "mifatielma";
    };
  };

  # Use the GRUB 2 boot loader.
  boot.loader.grub.enable = true;
  boot.loader.grub.version = 2;
  # boot.loader.grub.efiSupport = true;
  # boot.loader.grub.efiInstallAsRemovable = true;
  # boot.loader.efi.efiSysMountPoint = "/boot/efi";
  # Define on which hard drive you want to install Grub.
  boot.loader.grub.device = "/dev/sda"; # or "nodev" for efi only

  networking.hostName = "calanda";
  networking.domain = "ilanz.fh2.ch";
  networking.enableIPv6 = false; # TODO

  # Set your time zone.
  # time.timeZone = "Europe/Amsterdam";

  # List services that you want to enable:

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];

  # Define a user account. Don't forget to set a password with ‘passwd’.
  # users.users.jane = {
  #   isNormalUser = true;
  #   extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
  # };

  # This value determines the NixOS release with which your system is to be
  # compatible, in order to avoid breaking some software such as database
  # servers. You should change this only after NixOS release notes say you
  # should.
  system.stateVersion = "19.03"; # Did you read the comment?

}
